\name{polyshrink}
\alias{polyshrink}
\title{Adaptive Polyshrink Estimator}
\description{
  \code{polyshrink} adaptively shrinks the input statistics which are assumed to be 
  independent, standardized estimates of some underlying parameters.
}
\usage{
polyshrink(z)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z}{ a numerical vector holding standarized estimates. }
}
\value{
  Result is a vector of the shrunken estimates.
}
\references{ See "Adaptive variable selection is competitive with Bayes experts" (www-stat.wharton.upenn.edu/~stine) }
\author{ Bob Stine }
\note{   
  The parameters
  might be means of a normal distribution or regression coefficients. These are treated as a similarly scaled collection and shrunken toward zero.
}

\seealso{ polyshrink.wavelet }
\examples{
	# shrink vector of 4 estimates
	library(polyshrink)
	polyshrink(c(2,4,6,7))

	# plot the equivalent scalar estimator (which cannot borrow strength)
	x <- seq(-10,10,.2)
	plot(x, sapply(x,polyshrink),type="l")
	abline(a=0,b=1)

	# plot the estimator of first component in a vector with 65 elements
	z <- seq(-5.5,5.5,.1)
	signal <- qnorm((1:64)/65)
	beta1 <- function(x,signal) { w<-polyshrink(c(x,signal)); return(w[1]) }
    
	plot (z, sapply(z,beta1,signal+0), type="l", xlab="b", ylab="Polyshrink(b)")
        abline(0,1,col="slategray3")
	lines(z, sapply(z,beta1,signal+1), lty="66")
	lines(z, sapply(z,beta1,signal+1.15), lty="55")
	lines(z, sapply(z,beta1,signal+1.25), lty="44")
	lines(z, sapply(z,beta1,signal+1.35), lty="33")
	lines(z, sapply(z,beta1,signal+2), lty="22")

	legend(1,-1, title="Signal Mean", c("0","1.00","1.15","1.25","1.35","2.00"),
                                lty=c("solid","66","55","44","33","22"))
}
\keyword{ regression }
\keyword{ smooth }
\keyword{ multivariate }
