\name{polyshrink.wavelet}
\alias{polyshrink.wavelet}
\title{Polyshrink Smoothing of Wavelet Coefficients}
\description{
  \code{polyshrink.wavelet} adaptively shrinks the input wavelet coefficients
  which are assumed to be in the style produced by the \code{waveslim} package.
}
\usage{
polyshrink.wavelet(wc, max.level=0, scale=0)
}
\arguments{
  \item{wc}{ holds the list of raw wavelet coefficients }
  \item{max.level}{ indicates the last level of coefficients to be adjusted }
  \item{scale}{ a positive number indicates the known scale. Otherwise, the scale is estimated in each level using the median absolute deviation. }
}
\value{
  The result is the wavelet transform, with the coefficients in the \code{max.levels} lowest levels (those with most localized support) shrunken adaptively toward zero.
}
\references{ See "Adaptive variable selection is competitive with Bayes experts" (www-stat.wharton.upenn.edu/~stine) }
\author{ Bob Stine }
\note{ The wavelet coefficients at each resolution are shrunken collectively toward zero.  Only the coefficients of the lowest \code{max.level} (most localized) resolutions are smoothed.  }
\seealso{ polyshrink }
\examples{
	# be sure these libraries are present
	library(polyshrink)
	library(waveslim)

	# shrinkage for wavelets of noise
	n <- 256
	y <- rnorm(n)
	wt <- dwt(y, wf="la8", n.levels=log2(n), boundary="periodic")
	swt <- polyshrink.wavelet(wt)
	# narrow resolution estimates shrunken to near zero
        boxplot(swt[[1]])
	# see the estimator
	plot(wt[[1]], swt[[1]])

	# periodic estimate of a square wave buried in noise
        n <- 512
	x <- 1:n
        signal <- rep( c(-1,1), c(n/2,n/2) )
	y <- signal + .75*rnorm(n)
	plot(x,y); lines(x,signal)
	wt <- dwt(y, wf="la8", n.levels=log2(n), boundary="periodic")
        swt <- polyshrink.wavelet(wt, max.level=5)  # better to not smooth all
	est <- idwt(swt)
	lines(x,est, col=2)
}
\keyword{ regression }
\keyword{ smooth }
